==> koishi-plugin-group-expression-0.0.2.tgz: package/lib/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name2 in all)
    __defProp(target, name2, { get: all[name2], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Config: () => Config,
  apply: () => apply,
  name: () => name,
  usage: () => usage
});
module.exports = __toCommonJS(src_exports);
var import_koishi4 = require("koishi");

// src/config.ts
var import_koishi2 = require("koishi");

// src/file.ts
var import_node_fs = __toESM(require("node:fs"));
var import_node_path = __toESM(require("node:path"));

// src/log.ts
var import_koishi = require("koishi");
var logger = new import_koishi.Logger("group-expression");

// src/file.ts
var miaoBaseUrl = "./data/face/";
var getFilePath = /* @__PURE__ */ __name((...paths) => {
  const config = useConfig();
  const filePath = import_node_path.default.resolve(config.baseDir, "data", name, ...paths);
  if (!import_node_fs.default.existsSync(filePath)) {
    import_node_fs.default.mkdirSync(filePath, { recursive: true });
  }
  return filePath;
}, "getFilePath");
var readImage2base64 = /* @__PURE__ */ __name((filePath) => {
  if (filePath.startsWith(miaoBaseUrl)) {
    filePath = filePath.replace(miaoBaseUrl, "");
  }
  const buffer = import_node_fs.default.readFileSync(import_node_path.default.resolve(getFilePath("face"), ...filePath.split("/")));
  return buffer.toString("base64");
}, "readImage2base64");
var deleteImage = /* @__PURE__ */ __name((filePath) => {
  if (filePath.startsWith(miaoBaseUrl)) {
    filePath = filePath.replace(miaoBaseUrl, "");
  }
  import_node_fs.default.unlinkSync(import_node_path.default.resolve(getFilePath("face"), ...filePath.split("/")));
}, "deleteImage");
var saveBase642Image = /* @__PURE__ */ __name((base64, groupId = "global") => {
  const base64Data = base64.replace(/^data:image\/\w+;base64,/, "");
  const buffer = Buffer.from(base64Data, "base64");
  const fileType = base64.split(";").shift()?.split("/").pop() ?? "png";
  const fileName = `${groupId}_${Date.now()}.${fileType}`;
  const filePath = import_node_path.default.resolve(getFilePath("face", groupId), fileName);
  import_node_fs.default.writeFileSync(filePath, buffer);
  return miaoBaseUrl + groupId + "/" + fileName;
}, "saveBase642Image");
var saveImage = /* @__PURE__ */ __name((url, groupId = "global") => {
  return new Promise(async (resolve, reject) => {
    const respose = await fetch(url);
    const contentType = respose.headers.get("content-type");
    const imageType = contentType?.split("/")?.pop() ?? "png";
    const buffer = await respose.arrayBuffer();
    const fileName = `${groupId}_${Date.now()}.${imageType}`;
    const filePath = import_node_path.default.resolve(getFilePath("face", groupId), fileName);
    import_node_fs.default.writeFileSync(filePath, Buffer.from(buffer));
    resolve(miaoBaseUrl + groupId + "/" + fileName);
  });
}, "saveImage");
var saveJson = /* @__PURE__ */ __name((json, groupId = "global") => {
  const filePath = import_node_path.default.resolve(getFilePath("textJson"), `${groupId}.json`);
  import_node_fs.default.writeFileSync(filePath, JSON.stringify(json));
}, "saveJson");
var initJson = /* @__PURE__ */ __name(() => {
  const filePath = import_node_path.default.resolve(getFilePath("textJson"));
  const files = import_node_fs.default.readdirSync(filePath);
  const result = /* @__PURE__ */ new Map();
  files.forEach((file) => {
    if (file.endsWith(".json")) {
      const groupId = file.replace(".json", "");
      try {
        const content = import_node_fs.default.readFileSync(import_node_path.default.resolve(filePath, file), "utf-8");
        result.set(groupId, JSON.parse(content));
      } catch (error) {
        logger.error(`Failed to read json file: ${file}`, error);
      }
    }
  });
  return result;
}, "initJson");

// src/config.ts
var SchemaConfig = import_koishi2.Schema.intersect([
  import_koishi2.Schema.object({
    command: import_koishi2.Schema.object({
      addFaceCommand: import_koishi2.Schema.string().default("添加表情").description("添加表情命令"),
      deleteFaceCommand: import_koishi2.Schema.string().default("删除表情").description("删除表情命令"),
      searchFaceCommand: import_koishi2.Schema.string().default("搜索表情").description("搜索表情命令"),
      showFaceCommand: import_koishi2.Schema.string().default("查看表情").description("查看表情命令")
    }).collapse().description("指令注册设置"),
    keyLimitLength: import_koishi2.Schema.number().default(256).description("关键字长度限制"),
    debounceTime: import_koishi2.Schema.number().default(2).description("两次触发间隔时间(秒)"),
    addFaceTimeout: import_koishi2.Schema.number().default(60).description("添加表情超时时间(秒)"),
    selfId: import_koishi2.Schema.string().description("当前登录的QQ号"),
    adminList: import_koishi2.Schema.array(import_koishi2.Schema.string()).description("管理员列表"),
    pageSize: import_koishi2.Schema.number().default(10).description("每页显示表情数量")
  })
]);
var globalConfig;
var groupJsonMap;
var initConfig = /* @__PURE__ */ __name((ctx, config) => {
  globalConfig = {
    baseDir: ctx.baseDir,
    ctx,
    ...config
  };
  groupJsonMap = initJson();
  return globalConfig;
}, "initConfig");
var useConfig = /* @__PURE__ */ __name(() => {
  if (!globalConfig) {
    throw new Error("GroupExpression config is not initialized");
  }
  return globalConfig;
}, "useConfig");
var getGroupJson = /* @__PURE__ */ __name((groupId = "global") => {
  if (!groupJsonMap) {
    throw new Error("GroupExpression config is not initialized");
  }
  return groupJsonMap.get(groupId) ?? {};
}, "getGroupJson");
var updateGroupJson = /* @__PURE__ */ __name((groupId, groupJson) => {
  if (!groupJsonMap) {
    throw new Error("GroupExpression config is not initialized");
  }
  groupJsonMap.set(groupId, groupJson);
  saveJson(groupJson, groupId);
}, "updateGroupJson");

// src/face.ts
var import_koishi3 = require("koishi");
var creatFaceItem = /* @__PURE__ */ __name(async ({ user, elements, group_id }) => {
  const [img] = import_koishi3.h.select(elements, "img");
  const [image] = import_koishi3.h.select(elements, "image");
  const [text] = import_koishi3.h.select(elements, "text");
  if (img) {
    const url = img.attrs.src;
    const local = await saveImage(url, group_id);
    return [{
      type: "image",
      file: local,
      url: local,
      local,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  } else if (image) {
    const local = saveBase642Image(image.attrs.src, group_id);
    return [{
      type: "image",
      file: local,
      url: local,
      local,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  } else if (text) {
    return [{
      type: "text",
      text: text.attrs.content,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  }
  throw new Error("获取表情失败，请重试！");
}, "creatFaceItem");
var addFace = /* @__PURE__ */ __name(async ({ elements, user, group_id, key }) => {
  const groupJson = getGroupJson(group_id);
  const item = await creatFaceItem({ elements, user, group_id });
  if (!Array.isArray(groupJson[key])) {
    groupJson[key] = [];
  }
  groupJson[key].push(item);
  updateGroupJson(group_id, groupJson);
}, "addFace");
var deleteFace = /* @__PURE__ */ __name(async ({ group_id, key, index, user }) => {
  const config = useConfig();
  const groupJson = getGroupJson(group_id);
  const list = groupJson[key];
  if (!list || index < 0 || index > list.length - 1) {
    throw new Error("表情不存在");
  }
  const [item] = list[index];
  if (!item) {
    throw new Error("表情不存在");
  }
  if (!(!item.from_user.user_id || item.from_user.user_id === Number(user.id) || config.adminList.includes(user.id.toString()))) {
    throw new Error("无权限删除表情");
  }
  if (item.type === "image") {
    deleteImage(item.local);
  }
  groupJson[key].splice(index, 1);
  updateGroupJson(group_id, groupJson);
}, "deleteFace");
var searchFace = /* @__PURE__ */ __name(async ({ group_id, key }) => {
  const groupJson = getGroupJson(group_id);
  return groupJson[key] ?? [];
}, "searchFace");

// src/index.ts
var name = "group-expression";
var usage = `
<!DOCTYPE html>
<html lang="zh-CN">
<head>
<meta charset="UTF-8">
<title>插件使用说明</title>
</head>
<body>
<h1>插件使用说明</h1>
<p>本插件是完美兼容云崽的喵喵插件的表情管理。</p>
<p>如果你使用过云崽的喵喵插件的添加/删除功能，那你会更容易上手本插件的！</p>
<h2>数据迁移</h2>
<p>本插件支持从云崽的喵喵插件迁移数据。</p>
<p>迁移方法：</p>
<ul>
  <li>将喵喵云仔机器人的/Miao-Yunzai/data/目录下的face和textJson文件夹复制到koishi根目录data/group-expression/目录下</li>
  <p>目录示例：</p>
  <p>data/group-expression/face/[群号]/xxx.png</p>
  <p>data/group-expression/textJson/[群号].json</p>
</ul>
<h2>使用示例</h2>
<ul>
<li>添加表情：<code>#添加表情 [字符串]</code></li>
<li>删除表情：<code>#删除表情 [字符串] [序号]</code></li>
<li>搜索表情：<code>#搜索表情 [字符串] [页码]</code></li>
<li>查看表情：<code>#查看表情 [字符串] [序号]</code></li>

</ul>
</body>
</html>

`;
var Config = SchemaConfig;
function apply(ctx, config) {
  const { command, keyLimitLength, pageSize } = initConfig(ctx, config);
  const addFaceTempMap = /* @__PURE__ */ new Map();
  ctx.command(`${command.addFaceCommand} <message>`).alias("#添加表情").action(async ({ session }, message) => {
    if (!message.trim()) return `请输入要添加的关键字`;
    if (message.length > keyLimitLength) {
      return `关键字长度不能超过${keyLimitLength}个字符`;
    }
    const user = session.event.user;
    const channel = session.event.channel;
    if (!channel.id || !user.id) {
      return `添加失败，请在群聊中使用`;
    }
    addFaceTempMap.set(`${user.id}-${channel.id}`, {
      message,
      time: Date.now()
    });
    return `请发送要添加的表情`;
  });
  ctx.command(`${command.deleteFaceCommand} <key> <index:number>`).alias("#删除表情").action(async ({ session }, key, index) => {
    const user = session.event.user;
    const channel = session.event.channel;
    try {
      await deleteFace({ group_id: channel.id, key, index, user });
      return `删除表情成功！`;
    } catch (error) {
      return error?.message || `删除表情失败，请重试！`;
    }
  });
  ctx.command(`${command.searchFaceCommand} <key> [page:number]`).alias("#搜索表情").action(async ({ session }, key, page = 1) => {
    if (page < 1) {
      page = 1;
    }
    page = page - 1;
    const channel = session.event.channel;
    try {
      const list = await searchFace({ group_id: channel.id, key });
      if (list.length === 0) {
        return `没有找到表情`;
      }
      const maxPage = Math.ceil(list.length / pageSize);
      if (page > maxPage) {
        return `没有更多页了`;
      }
      const result = list.slice(page * pageSize, (page + 1) * pageSize).map(([item], index) => {
        switch (item.type) {
          case "text":
            return `序号：${index}
内容：${item.text.slice(0, 10) + (item.text.length > 10 ? "..." : "")}
`;
          case "image":
            return `序号：${index}
内容：[图片]
`;
        }
      }).join("\n");
      if (!result.trim()) return `没有找到表情`;
      return result;
    } catch (error) {
      return error?.message || `搜索表情失败，请重试！`;
    }
  });
  ctx.command(`${command.showFaceCommand} <key> <index:number>`).alias("#查看表情").action(async ({ session }, key, index) => {
    const channel = session.event.channel;
    try {
      const list = await searchFace({ group_id: channel.id, key });
      if (index > list.length - 1 || index < 0) {
        return `没有这个序号`;
      }
      const [item] = list[index];
      if (!item) return `没有这个序号`;
      switch (item.type) {
        case "text":
          return item.text;
        case "image":
          const base64 = readImage2base64(item.local);
          return (0, import_koishi4.h)("img", { src: `data:image/png;base64,${base64}` });
      }
    } catch (error) {
      return error?.message || `查看表情失败，请重试！`;
    }
  });
  let lastTriggerTime = 0;
  ctx.on("message", async (session) => {
    if (Date.now() - lastTriggerTime < config.debounceTime * 1e3) return;
    const user = session.event.user;
    if (user.id === config.selfId) return;
    const channel = session.event.channel;
    const cache = addFaceTempMap.get(`${user.id}-${channel.id}`);
    if (cache) {
      if (Date.now() - cache.time > 1e3 * config.addFaceTimeout) {
        addFaceTempMap.delete(`${user.id}-${channel.id}`);
        session.send(`添加表情超时，请重新添加！`);
        return;
      }
      try {
        await addFace({
          elements: session.elements,
          user,
          group_id: channel.id,
          key: cache.message
        });
        addFaceTempMap.delete(`${user.id}-${channel.id}`);
        session.send(`添加表情成功！`);
        return;
      } catch (error) {
        session.send(error?.message || `添加表情失败，请重试！`);
        addFaceTempMap.delete(`${user.id}-${channel.id}`);
        return;
      }
    }
    const [searchKey] = import_koishi4.h.select(session.elements, "text");
    if (searchKey?.attrs?.content?.trim()) {
      const list = await searchFace({ group_id: channel.id, key: searchKey.attrs.content });
      if (list.length === 0) return;
      const radomIndex = Math.floor(Math.random() * list.length);
      const [item] = list[radomIndex];
      if (!item) return;
      switch (item.type) {
        case "text":
          session.send(item.text);
          break;
        case "image":
          const base64 = readImage2base64(item.local);
          session.send((0, import_koishi4.h)("img", { src: `data:image/png;base64,${base64}` }));
          break;
      }
      lastTriggerTime = Date.now();
    }
  });
}
__name(apply, "apply");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Config,
  apply,
  name,
  usage
});

==> koishi-plugin-group-expression-0.0.3.tgz: package/lib/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name2 in all)
    __defProp(target, name2, { get: all[name2], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Config: () => Config,
  apply: () => apply,
  name: () => name,
  usage: () => usage
});
module.exports = __toCommonJS(src_exports);
var import_koishi4 = require("koishi");

// src/config.ts
var import_koishi2 = require("koishi");

// src/file.ts
var import_node_fs = __toESM(require("node:fs"));
var import_node_path = __toESM(require("node:path"));

// src/log.ts
var import_koishi = require("koishi");
var logger = new import_koishi.Logger("group-expression");

// src/file.ts
var miaoBaseUrl = "./data/face/";
var getFilePath = /* @__PURE__ */ __name((...paths) => {
  const config = useConfig();
  const filePath = import_node_path.default.resolve(config.baseDir, "data", name, ...paths);
  if (!import_node_fs.default.existsSync(filePath)) {
    import_node_fs.default.mkdirSync(filePath, { recursive: true });
  }
  return filePath;
}, "getFilePath");
var readImage2base64 = /* @__PURE__ */ __name((filePath) => {
  if (filePath.startsWith(miaoBaseUrl)) {
    filePath = filePath.replace(miaoBaseUrl, "");
  }
  const buffer = import_node_fs.default.readFileSync(import_node_path.default.resolve(getFilePath("face"), ...filePath.split("/")));
  return buffer.toString("base64");
}, "readImage2base64");
var deleteImage = /* @__PURE__ */ __name((filePath) => {
  if (filePath.startsWith(miaoBaseUrl)) {
    filePath = filePath.replace(miaoBaseUrl, "");
  }
  import_node_fs.default.unlinkSync(import_node_path.default.resolve(getFilePath("face"), ...filePath.split("/")));
}, "deleteImage");
var saveBase642Image = /* @__PURE__ */ __name((base64, groupId = "global") => {
  const base64Data = base64.replace(/^data:image\/\w+;base64,/, "");
  const buffer = Buffer.from(base64Data, "base64");
  const fileType = base64.split(";").shift()?.split("/").pop() ?? "png";
  const fileName = `${groupId}_${Date.now()}.${fileType}`;
  const filePath = import_node_path.default.resolve(getFilePath("face", groupId), fileName);
  import_node_fs.default.writeFileSync(filePath, buffer);
  return miaoBaseUrl + groupId + "/" + fileName;
}, "saveBase642Image");
var saveImage = /* @__PURE__ */ __name((url, groupId = "global") => {
  return new Promise(async (resolve, reject) => {
    const respose = await fetch(url);
    const contentType = respose.headers.get("content-type");
    const imageType = contentType?.split("/")?.pop() ?? "png";
    const buffer = await respose.arrayBuffer();
    const fileName = `${groupId}_${Date.now()}.${imageType}`;
    const filePath = import_node_path.default.resolve(getFilePath("face", groupId), fileName);
    import_node_fs.default.writeFileSync(filePath, Buffer.from(buffer));
    resolve(miaoBaseUrl + groupId + "/" + fileName);
  });
}, "saveImage");
var saveJson = /* @__PURE__ */ __name((json, groupId = "global") => {
  const filePath = import_node_path.default.resolve(getFilePath("textJson"), `${groupId}.json`);
  import_node_fs.default.writeFileSync(filePath, JSON.stringify(json));
}, "saveJson");
var initJson = /* @__PURE__ */ __name(() => {
  const filePath = import_node_path.default.resolve(getFilePath("textJson"));
  const files = import_node_fs.default.readdirSync(filePath);
  const result = /* @__PURE__ */ new Map();
  files.forEach((file) => {
    if (file.endsWith(".json")) {
      const groupId = file.replace(".json", "");
      try {
        const content = import_node_fs.default.readFileSync(import_node_path.default.resolve(filePath, file), "utf-8");
        result.set(groupId, JSON.parse(content));
      } catch (error) {
        logger.error(`Failed to read json file: ${file}`, error);
      }
    }
  });
  return result;
}, "initJson");

// src/config.ts
var SchemaConfig = import_koishi2.Schema.intersect([
  import_koishi2.Schema.object({
    command: import_koishi2.Schema.object({
      addFaceCommand: import_koishi2.Schema.string().default("#添加表情").description("添加表情命令"),
      deleteFaceCommand: import_koishi2.Schema.string().default("#删除表情").description("删除表情命令"),
      searchFaceCommand: import_koishi2.Schema.string().default("#搜索表情").description("搜索表情命令")
    }).collapse().description("指令注册设置"),
    keyLimitLength: import_koishi2.Schema.number().default(256).description("关键字长度限制"),
    debounceTime: import_koishi2.Schema.number().default(2).description("两次触发间隔时间(秒)"),
    addFaceTimeout: import_koishi2.Schema.number().default(60).description("添加表情超时时间(秒)"),
    selfId: import_koishi2.Schema.string().description("当前登录的QQ号"),
    adminList: import_koishi2.Schema.array(import_koishi2.Schema.string()).description("管理员列表"),
    pageSize: import_koishi2.Schema.number().default(2).description("每页显示表情数量")
  })
]);
var globalConfig;
var groupJsonMap;
var initConfig = /* @__PURE__ */ __name((ctx, config) => {
  globalConfig = {
    baseDir: ctx.baseDir,
    ctx,
    ...config
  };
  groupJsonMap = initJson();
  return globalConfig;
}, "initConfig");
var useConfig = /* @__PURE__ */ __name(() => {
  if (!globalConfig) {
    throw new Error("GroupExpression config is not initialized");
  }
  return globalConfig;
}, "useConfig");
var getGroupJson = /* @__PURE__ */ __name((groupId = "global") => {
  if (!groupJsonMap) {
    throw new Error("GroupExpression config is not initialized");
  }
  return groupJsonMap.get(groupId) ?? {};
}, "getGroupJson");
var updateGroupJson = /* @__PURE__ */ __name((groupId, groupJson) => {
  if (!groupJsonMap) {
    throw new Error("GroupExpression config is not initialized");
  }
  groupJsonMap.set(groupId, groupJson);
  saveJson(groupJson, groupId);
}, "updateGroupJson");

// src/face.ts
var import_koishi3 = require("koishi");
var creatFaceItem = /* @__PURE__ */ __name(async ({ user, elements, group_id }) => {
  const [img] = import_koishi3.h.select(elements, "img");
  const [image] = import_koishi3.h.select(elements, "image");
  const [text] = import_koishi3.h.select(elements, "text");
  if (img) {
    const url = img.attrs.src;
    const local = await saveImage(url, group_id);
    return [{
      type: "image",
      file: local,
      url: local,
      local,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  } else if (image) {
    const local = saveBase642Image(image.attrs.src, group_id);
    return [{
      type: "image",
      file: local,
      url: local,
      local,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  } else if (text) {
    return [{
      type: "text",
      text: text.attrs.content,
      from_user: {
        card: user.name,
        nickname: user.name,
        user_id: Number(user.id)
      }
    }];
  }
  throw new Error("获取表情失败，请重试！");
}, "creatFaceItem");
var addFace = /* @__PURE__ */ __name(async ({ elements, user, group_id, key }) => {
  const groupJson = getGroupJson(group_id);
  const item = await creatFaceItem({ elements, user, group_id });
  if (!Array.isArray(groupJson[key])) {
    groupJson[key] = [];
  }
  groupJson[key].push(item);
  updateGroupJson(group_id, groupJson);
}, "addFace");
var deleteFace = /* @__PURE__ */ __name(async ({ group_id, key, index, user }) => {
  const config = useConfig();
  const groupJson = getGroupJson(group_id);
  const list = groupJson[key];
  if (!list || index < 0 || index > list.length - 1) {
    throw new Error("表情不存在");
  }
  const [item] = list[index];
  if (!item) {
    throw new Error("表情不存在");
  }
  if (!(!item.from_user.user_id || item.from_user.user_id === Number(user.id) || config.adminList.includes(user.id.toString()))) {
    throw new Error("无权限删除表情");
  }
  if (item.type === "image") {
    deleteImage(item.local);
  }
  groupJson[key].splice(index, 1);
  updateGroupJson(group_id, groupJson);
}, "deleteFace");
var searchFace = /* @__PURE__ */ __name(async ({ group_id, key }) => {
  const groupJson = getGroupJson(group_id);
  return groupJson[key] ?? [];
}, "searchFace");

// src/index.ts
var name = "group-expression";
var usage = `
<!DOCTYPE html>
<html lang="zh-CN">
<head>
<meta charset="UTF-8">
<title>插件使用说明</title>
</head>
<body>
<h1>插件使用说明</h1>
<p>本插件是完美兼容云崽的喵喵插件的表情管理。</p>
<p>如果你使用过云崽的喵喵插件的添加/删除功能，那你会更容易上手本插件的！</p>
<h2>数据迁移</h2>
<p>本插件支持从云崽的喵喵插件迁移数据。</p>
<p>迁移方法：</p>
<ul>
  <li>将喵喵云仔机器人的/Miao-Yunzai/data/目录下的face和textJson文件夹复制到koishi根目录data/group-expression/目录下</li>
  <p>目录示例：</p>
  <p>data/group-expression/face/[群号]/xxx.png</p>
  <p>data/group-expression/textJson/[群号].json</p>
</ul>
<h2>使用示例</h2>
<ul>
<li>添加表情：<code>#添加表情 [字符串]</code></li>
<li>删除表情：<code>#删除表情 [字符串] [序号]</code></li>
<li>搜索表情：<code>#搜索表情 [字符串] [页码]</code></li>
<li>查看表情：<code>#查看表情 [字符串] [序号]</code></li>

</ul>
</body>
</html>

`;
var Config = SchemaConfig;
function apply(ctx, config) {
  const { command, keyLimitLength, pageSize } = initConfig(ctx, config);
  ctx.command(`${command.addFaceCommand} <message>`).action(async ({ session }, message) => {
    if (!message.trim()) return `请输入要添加的关键字`;
    if (message.length > keyLimitLength) {
      return `关键字长度不能超过${keyLimitLength}个字符`;
    }
    const user = session.event.user;
    const channel = session.event.channel;
    if (!channel.id || !user.id) {
      return `添加失败，请在群聊中使用`;
    }
    session.send("请发送要添加的表情");
    try {
      const res = await session.prompt(5e3);
      const elements = import_koishi4.h.parse(res);
      await addFace({
        elements,
        user,
        group_id: channel.id,
        key: message
      });
      return `添加表情成功！`;
    } catch (error) {
      return `${error?.message || "添加表情失败,请重试"}`;
    }
  });
  ctx.command(`${command.deleteFaceCommand} <key:text>`).action(async ({ session }, key) => {
    const user = session.event.user;
    const channel = session.event.channel;
    if (!key.trim()) return `请输入要删除的关键词：${command.deleteFaceCommand} 关键词`;
    let page = 0;
    const list = await searchFace({ group_id: channel.id, key });
    if (list.length === 0) return `没有找到表情`;
    if (list.length === 1) {
      try {
        await deleteFace({ group_id: channel.id, key, index: 0, user });
        return `删除表情成功！`;
      } catch (error) {
        return `${error?.message || "删除表情失败,请重试"}`;
      }
    }
    while (true) {
      const pageList = list.slice(page * pageSize, (page + 1) * pageSize);
      const resList = [`${key}的搜索结果（共计${list.length}条）：
`];
      pageList.map(([item], index) => {
        resList.push(`${index + 1}:
`);
        switch (item.type) {
          case "text":
            resList.push(`${item.text.slice(0, 20) + (item.text.length > 20 ? "..." : "")}
`);
            break;
          case "image":
            const base64 = readImage2base64(item.local);
            resList.push((0, import_koishi4.h)("img", { src: `data:image/png;base64,${base64}` }));
            break;
        }
      });
      resList.push(`
页码：${page + 1}/${Math.ceil(list.length / pageSize)}
跳转页码指令示例：跳转 1
请输入要删除的序号：`);
      session.send(resList);
      const res = await session.prompt(1e4);
      if (!res || !res?.trim()) {
        session.send("本次操作已结束。");
        break;
      }
      if (res.trim().startsWith("跳转")) {
        const pageNum = parseInt(res?.trim()?.split(" ")?.pop());
        if (isNaN(pageNum)) {
          session.send(`请输入正确的页码`);
          continue;
        }
        if (pageNum > 0 && pageNum <= Math.ceil(list.length / pageSize)) {
          page = pageNum - 1;
          continue;
        }
        session.send(`没有这个页码`);
      }
      const input = parseInt(res?.trim());
      if (isNaN(input)) {
        session.send(`请输入正确的序号`);
        continue;
      }
      if (input > 0 && input <= pageList.length) {
        try {
          await deleteFace({ group_id: channel.id, key, index: input - 1, user });
          return `删除表情成功！`;
        } catch (error) {
          return `${error?.message || "删除表情失败,请重试"}`;
        }
      }
      session.send(`没有这个序号`);
    }
  });
  ctx.command(`${command.searchFaceCommand} <key>`).action(async ({ session }, key) => {
    const channel = session.event.channel;
    if (!key.trim()) return `请输入要搜索的关键词：${command.searchFaceCommand} 关键词`;
    let page = 0;
    const list = await searchFace({ group_id: channel.id, key });
    if (list.length === 0) return `没有找到表情`;
    while (true) {
      const pageList = list.slice(page * pageSize, (page + 1) * pageSize);
      const resList = [`${key}的搜索结果（共计${list.length}条）：
`];
      pageList.map(([item], index) => {
        resList.push(`${index + 1}:
`);
        switch (item.type) {
          case "text":
            resList.push(`${item.text.slice(0, 20) + (item.text.length > 20 ? "..." : "")}
`);
            break;
          case "image":
            const base64 = readImage2base64(item.local);
            resList.push((0, import_koishi4.h)("img", { src: `data:image/png;base64,${base64}` }));
            break;
        }
      });
      resList.push(`
页码：${page + 1}/${Math.ceil(list.length / pageSize)}
跳转页码指令示例：跳转 1`);
      session.send(resList);
      const res = await session.prompt(1e4);
      if (!res || !res?.trim()) {
        session.send("本次搜索已结束。");
        break;
      }
      if (res.trim().startsWith("跳转")) {
        const pageNum = parseInt(res?.trim()?.split(" ")?.pop());
        if (isNaN(pageNum)) {
          session.send(`请输入正确的页码`);
          continue;
        }
        if (pageNum > 0 && pageNum <= Math.ceil(list.length / pageSize)) {
          page = pageNum - 1;
          continue;
        }
        session.send(`没有这个页码`);
      }
    }
  });
  let lastTriggerTime = 0;
  ctx.on("message", async (session) => {
    if (Date.now() - lastTriggerTime < config.debounceTime * 1e3) return;
    const user = session.event.user;
    if (user.id === config.selfId) return;
    const channel = session.event.channel;
    const [searchKey] = import_koishi4.h.select(session.elements, "text");
    if (searchKey?.attrs?.content?.trim()) {
      const list = await searchFace({ group_id: channel.id, key: searchKey.attrs.content });
      if (list.length === 0) return;
      const radomIndex = Math.floor(Math.random() * list.length);
      const [item] = list[radomIndex];
      if (!item) return;
      switch (item.type) {
        case "text":
          session.send(item.text);
          break;
        case "image":
          const base64 = readImage2base64(item.local);
          session.send((0, import_koishi4.h)("img", { src: `data:image/png;base64,${base64}` }));
          break;
      }
      lastTriggerTime = Date.now();
    }
  });
}
__name(apply, "apply");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Config,
  apply,
  name,
  usage
});
